"use strict";
/*
 * Copyright (c) 2022.
 * Author Peter Placzek (tada5hi)
 * For the full copyright and license information,
 * view the LICENSE file that was distributed with this source code.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupSocketMiddleware = void 0;
const core_1 = require("@typescript-auth/core");
const domains_1 = require("@typescript-auth/domains");
const utils_1 = require("../../utils");
function setupSocketMiddleware(context) {
    const tokenCache = (0, utils_1.initTokenCache)(context.redis, context.redisPrefix);
    const tokenAPIClient = new domains_1.TokenAPI(context.axios);
    return (socket, next) => __awaiter(this, void 0, void 0, function* () {
        const { token } = socket.handshake.auth;
        if (!token) {
            return next();
        }
        let data;
        try {
            data = yield (0, utils_1.verifyToken)({
                token,
                tokenCache,
                tokenAPIClient,
            });
        }
        catch (e) {
            return next(e);
        }
        const _a = data.entity.data, { permissions } = _a, entity = __rest(_a, ["permissions"]);
        switch (data.entity.type) {
            case 'robot':
                socket.data.robotId = entity.id;
                socket.data.robot = entity;
                break;
            case 'user':
                socket.data.userId = entity.id;
                socket.data.user = entity;
                break;
        }
        socket.data.token = token;
        socket.data.permissions = permissions;
        socket.data.ability = new core_1.AbilityManager(permissions);
        return next();
    });
}
exports.setupSocketMiddleware = setupSocketMiddleware;
//# sourceMappingURL=module.js.map